@@ -11,13 +11,12 @@ from mootdx.utils import TqdmUpTo
 def download(downdir, filename):
     """
     带进度条下载函数
-
     :param downdir:
     :param filename:
     :return:
     """
 
-    with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
+    with TqdmUpTo(unit="B", unit_scale=True, miniters=1, ascii=True) as t:
         financial.Financial().fetch_only(report_hook=t.update_to, filename=filename, downdir=downdir)
 
     return True
@@ -32,24 +31,24 @@ async def fetch_file(downdir, file_obj):
     :return:
     """
 
-    filepath = Path(downdir) / file_obj['filename']
+    filepath = Path(downdir) / file_obj["filename"]
 
     # 判断文件是否存在, 验证文件名和哈希值
-    if filepath.exists() and file_obj['hash'] == hashlib.md5(open(filepath, 'rb').read()).hexdigest():
-        logger.warning(f'文件已经存在: {filepath}')
+    if filepath.exists() and file_obj["hash"] == hashlib.md5(open(filepath, "rb").read()).hexdigest():
+        logger.warning(f"文件已经存在: {filepath}")
         return None
 
     result = await asyncio.get_event_loop().run_in_executor(
-        None, partial(financial.Financial().fetch_only, report_hook=None, filename=file_obj['filename'], downdir=downdir)
+        None,
+        partial(financial.Financial().fetch_only, report_hook=None, filename=file_obj["filename"], downdir=downdir),
     )
 
     return result
 
 
 class Affair(object):
-
     @staticmethod
-    def parse(downdir='.', filename=None, **kwargs):
+    def parse(downdir=".", filename=None, **kwargs):
         """
         按目录解析文件
 
@@ -59,16 +58,16 @@ class Affair(object):
         """
 
         if not filename:
-            logger.critical('文件名不能为空!')
+            logger.critical("文件名不能为空!")
             return None
 
         filepath = Path(downdir) / filename
-        Affair.fetch(downdir, filename)
+        filepath.exists() or Affair.fetch(downdir, filename)
 
         if Path(filepath).exists():
             return financial.FinancialReader().to_data(filepath, **kwargs)
 
-        logger.warning(f'文件不存在：{filename}')
+        logger.warning(f"文件不存在：{filename}")
 
         return None
 
@@ -97,16 +96,16 @@ class Affair(object):
 
         history = financial.FinancialList()
         crawler = financial.Financial()
-        downdir = downdir or '.'
+        downdir = downdir or "."
 
         if not Path(downdir).is_dir():
-            logger.warning('下载目录不存在, 进行创建.')
+            logger.warning("下载目录不存在, 进行创建.")
             Path(downdir).mkdir(parents=True)
 
         if filename:
-            logger.info('下载文件 {}.'.format(filename))
+            logger.info("下载文件 {}.".format(filename))
 
-            with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
+            with TqdmUpTo(unit="B", unit_scale=True, miniters=1, ascii=True) as t:
                 crawler.fetch_only(report_hook=t.update_to, filename=filename, downdir=downdir)
 
             return True
