@@ -1,8 +1,8 @@
 import math
 import pandas
 import pandas as pd
-from pytdx.exhq import TdxExHq_API
-from pytdx.hq import TdxHq_API
+from tdxpy.exhq import TdxExHq_API
+from tdxpy.hq import TdxHq_API
 from tenacity import retry
 from tenacity import retry_if_exception_type
 from tenacity import retry_if_result
@@ -12,7 +12,7 @@ from tqdm import tqdm
 from mootdx import config
 from mootdx.consts import MARKET_SH
 from mootdx.consts import return_last_value
-from mootdx.logger import logger, reset as logger_reset
+from mootdx.logger import logger
 from mootdx.server import check_server
 from mootdx.utils import get_frequency
 from mootdx.utils import get_stock_market
@@ -22,7 +22,7 @@ from mootdx.utils import to_data
 
 class Quotes(object):
     @staticmethod
-    def factory(market='std', **kwargs):
+    def factory(market="std", **kwargs):
         """
         股票市场 工厂方法
 
@@ -30,47 +30,64 @@ class Quotes(object):
         :param kwargs:  可变参数
         :return: object
         """
-        if market == 'ext':
+
+        logger.debug(kwargs)
+
+        if market == "ext":
             return ExtQuotes(**kwargs)
 
         return StdQuotes(**kwargs)
 
 
+def valid_server(server):
+    import ipaddress
+
+    if isinstance(server, tuple) or isinstance(server, list):
+        try:
+            address, port = server
+            ipaddress.ip_address(address)
+            return address, int(port)
+        except Exception:
+            raise ValueError('Server 格式错误. 例如: server = ("127.0.0.1", 2272)')
+
+    return None
+
+
 class BaseQuotes(object):
     client = None
     bestip = None
+    server = None
 
-    def __init__(self, bestip: bool = False, server: list = None, timeout: int = None, verbose=0, **kwargs) -> None:
+    def __init__(self, server=None, bestip: bool = False, timeout: int = None, verbose=0, **kwargs) -> None:
 
-        logger_reset(verbose=verbose)
+        logger.debug(f"server => {server}")
+        self.server = valid_server(server)
 
-        logger.debug(f'verify=>{bestip}')
-        bestip and check_server()
+        logger.debug(f"bestip => {bestip}")
+        (bestip or (not config.get("BESTIP"))) and check_server()
 
-        logger.debug(f'timeout=>{timeout}')
+        logger.debug(f"timeout => {timeout}")
         self.timeout = timeout if timeout else 15
 
-        logger.debug('config.setup()')
-
+        logger.debug("config.setup()")
         config.setup()
-        server and config.set('BESTIP', {'HQ': server})
 
     def __del__(self):
-        logger.debug('call __del__')
+        logger.debug("call __del__")
         self.close()
 
     def reconnect(self):
         if self.closed:
-            logger.debug('服务器连接已断开，正进行重新连接...')
+            logger.debug("服务器连接已断开，正进行重新连接...")
             self.client.connect(*self.bestip)
 
     def close(self):
-        logger.debug('close')
-        hasattr(self.client, 'close') and self.client.close()
+        logger.debug("close")
+        hasattr(self.client, "close") and self.client.close()
 
     @property
     def closed(self) -> bool:
-        if not hasattr(self.client.client, '_closed') or getattr(self.client.client, '_closed'):
+        if not hasattr(self.client.client, "_closed") or getattr(self.client.client, "_closed"):
             return True
 
         return False
@@ -93,49 +110,58 @@ def check_empty(value):
 
     # 判断状态空，则重连接
     if instance and _empty:
-        logger.info('重新连接服务器')
-        instance.client.connect(*instance.bestip)
+        logger.info("重新连接服务器")
+        instance.client.connect(*instance.server)
 
     return _empty
 
 
 class StdQuotes(BaseQuotes):
     """
-    股票市场实时行情 """
+    股票市场实时行情"""
 
-    def __init__(self, bestip=False, timeout=15, **kwargs):
-        """ 构造函数
+    def __init__(self, server=None, bestip=False, timeout=15, **kwargs):
+        """构造函数
 
         :param bestip:  最佳 IP
         :param timeout: 超时时间
         :param kwargs:  可变参数
         """
 
-        super(StdQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
+        super().__init__(bestip=bestip, timeout=timeout, server=server, **kwargs)
+        self.server and config.set("BESTIP", {"HQ": self.server})
 
         try:
-            config.get('SERVER').get('HQ')[0]
+            config.get("SERVER").get("HQ")[0]
         except ValueError as ex:
             logger.warning(ex)
         finally:
-            default = config.get('SERVER').get('HQ')[0][1:]
-            self.bestip = config.get('BESTIP').get('HQ', default)
+            default = config.get("SERVER").get("HQ")[0][1:]
+            self.server = config.get("BESTIP").get("HQ", default)
 
-        for x in ['verbose', 'server', 'quiet']:
+        for x in ["verbose", "server", "quiet"]:
             if x in kwargs.keys():
                 del kwargs[x]
 
-        self.client = TdxHq_API(raise_exception=False, **kwargs)
-        self.client.connect(*self.bestip)
+        self.client = TdxHq_API(raise_exception=False, auto_retry=True, **kwargs)
+        self.client.connect(*self.server, time_out=timeout)
 
         global instance
         instance = self
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def traffic(self):
         return self.client.get_traffic_stats()
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def quotes(self, symbol=None, **kwargs):
         """
         获取实时日行情数据
@@ -155,8 +181,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def bars(self, symbol="000001", frequency=9, start=0, offset=100, **kwargs):
         """
         获取实时日K线数据
 
@@ -173,7 +203,11 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def stock_count(self, market=MARKET_SH):
         """
         获取市场股票数量
@@ -186,7 +220,11 @@ class StdQuotes(BaseQuotes):
 
         return result
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def stocks(self, market=MARKET_SH):
         """
         获取股票列表
@@ -200,12 +238,16 @@ class StdQuotes(BaseQuotes):
 
         for start in tqdm(range(0, counts, 1000)):
             result = self.client.get_security_list(market=market, start=start)
-            stocks = (pandas.concat([stocks, to_data(result)], ignore_index=True) if start > 1 else to_data(result))
+            stocks = pandas.concat([stocks, to_data(result)], ignore_index=True) if start > 1 else to_data(result)
 
         return stocks
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def index_bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def index_bars(self, symbol="000001", frequency=9, start=0, offset=100, **kwargs):
         """
         获取指数k线
 
@@ -223,8 +265,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def minute(self, symbol='', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def minute(self, symbol="", **kwargs):
         """
         获取实时分时数据
 
@@ -237,8 +283,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def minutes(self, symbol='', date='20191023', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def minutes(self, symbol="", date="20191023", **kwargs):
         """
         分时历史数据
 
@@ -252,8 +302,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def transaction(self, symbol='', start=0, offset=10, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def transaction(self, symbol="", start=0, offset=10, **kwargs):
         """
         查询分笔成交
 
@@ -268,8 +322,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def transactions(self, symbol='', start=0, offset=10, date='20170209', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def transactions(self, symbol="", start=0, offset=10, date="20170209", **kwargs):
         """
         查询历史分笔成交
 
@@ -281,12 +339,18 @@ class StdQuotes(BaseQuotes):
         """
 
         market = get_stock_market(symbol, string=False)
-        result = self.client.get_history_transaction_data(market=market, code=symbol, start=start, count=offset, date=int(date))
+        result = self.client.get_history_transaction_data(
+            market=market, code=symbol, start=start, count=offset, date=int(date)
+        )
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def F10C(self, symbol=''):  # noqa
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def F10C(self, symbol=""):  # noqa
         """
         查询公司信息目录
 
@@ -299,8 +363,12 @@ class StdQuotes(BaseQuotes):
 
         return result
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def F10(self, symbol='', name=''):  # noqa
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def F10(self, symbol="", name=""):  # noqa
         """
         读取公司信息详情
 
@@ -319,22 +387,28 @@ class StdQuotes(BaseQuotes):
 
         if name:
             for x in category:
-                if x['name'] == name:
+                if x["name"] == name:
                     return self.client.get_company_info_content(
                         market=market,
                         code=symbol,
-                        filename=x['filename'],
-                        start=x['start'],
-                        length=x['length'],
+                        filename=x["filename"],
+                        start=x["start"],
+                        length=x["length"],
                     )
 
         for x in category:
-            result[x['name']] = self.client.get_company_info_content(market=market, code=symbol, filename=x['filename'], start=x['start'], length=x['length'])
+            result[x["name"]] = self.client.get_company_info_content(
+                market=market, code=symbol, filename=x["filename"], start=x["start"], length=x["length"]
+            )
 
         return result
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def xdxr(self, symbol='', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def xdxr(self, symbol="", **kwargs):
         """
         读取除权除息信息
 
@@ -347,8 +421,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def finance(self, symbol='000001', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def finance(self, symbol="000001", **kwargs):
         """
         读取财务信息
 
@@ -361,8 +439,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def k(self, symbol='', begin=None, end=None):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def k(self, symbol="", begin=None, end=None):
         """
         读取k线信息
 
@@ -381,16 +463,26 @@ class StdQuotes(BaseQuotes):
     def get_k_data(self, code, start_date, end_date):
 
         # !! todo
-        data = pd.concat([self.client.to_df(self.client.get_security_bars(9, get_stock_market(code), code, (9 - i) * 800, 800)) for i in range(10)], axis=0)
-        data = data.assign(date=data['datetime'].apply(lambda x: str(x)[0:10])).assign(code=str(code))
-        data = data.set_index('date', drop=False, inplace=False)
-        data = data.drop(['year', 'month', 'day', 'hour', 'minute', 'datetime'], axis=1)[start_date:end_date]
-        data = data.assign(date=data['date'].apply(lambda x: str(x)[0:10]))
+        data = pd.concat(
+            [
+                self.client.to_df(self.client.get_security_bars(9, get_stock_market(code), code, (9 - i) * 800, 800))
+                for i in range(10)
+            ],
+            axis=0,
+        )
+        data = data.assign(date=data["datetime"].apply(lambda x: str(x)[0:10])).assign(code=str(code))
+        data = data.set_index("date", drop=False, inplace=False)
+        data = data.drop(["year", "month", "day", "hour", "minute", "datetime"], axis=1)[start_date:end_date]
+        data = data.assign(date=data["date"].apply(lambda x: str(x)[0:10]))
 
         return data
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def index(self, symbol='000001', market=MARKET_SH, frequency=9, start=1, offset=2, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def index(self, symbol="000001", market=MARKET_SH, frequency=9, start=1, offset=2, **kwargs):
         """
         获取指数k线
 
@@ -420,8 +512,12 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def block(self, tofile='block.dat', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def block(self, tofile="block.dat", **kwargs):
         """
         获取证券板块信息
 
@@ -434,11 +530,11 @@ class StdQuotes(BaseQuotes):
 
 
 class ExtQuotes(BaseQuotes):
-    """ 扩展市场实时行情 """
+    """扩展市场实时行情"""
 
-    bestip = ('112.74.214.43', 7727)
+    # server = ("112.74.214.43", 7727)
 
-    def __init__(self, bestip=False, timeout=15, **kwargs):
+    def __init__(self, server: list = None, bestip=False, timeout=15, **kwargs):
         """
         构造函数
 
@@ -446,23 +542,31 @@ class ExtQuotes(BaseQuotes):
         :param timeout: 超时时间
         :param kwargs:  可变参数
         """
-        super(ExtQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
+        super().__init__(bestip=bestip, timeout=timeout, server=server, **kwargs)
+        self.server and config.set("BESTIP", {"EX": self.server})
 
-        logger.warning('目前扩展市场行情接口已经失效, 后期有望修复.')
+        logger.warning("目前扩展市场行情接口已经失效, 后期有望修复.")
 
         try:
-            config.get('SERVER').get('EX')[0]
-        except ValueError:
-            server.bestip()
+            config.get("SERVER").get("EX")[0]
+        except ValueError as ex:
+            logger.warning(ex)
         finally:
-            default = config.get('SERVER').get('EX')[0]
-            self.bestip = config.get('BESTIP').get('EX', default)
+            default = config.get("SERVER").get("EX")[0]
+            self.server = config.get("BESTIP").get("EX", default)
 
-        if kwargs.get('quiet'):
-            del kwargs['quiet']
+        for x in ["verbose", "server", "quiet"]:
+            if x in kwargs.keys():
+                del kwargs[x]
 
-        self.client = TdxExHq_API(**kwargs)
-        self.client.connect(*self.bestip)
+        try:
+            self.client = TdxExHq_API(raise_exception=False, auto_retry=True, **kwargs)
+            self.client.connect(*self.server)
+        except Exception:
+            logger.error('服务器连接超时.')
+
+        global instance
+        instance = self
 
     @staticmethod
     def validate(market, symbol):
@@ -475,16 +579,20 @@ class ExtQuotes(BaseQuotes):
         """
 
         if not market:
-            if len(symbol.split('#')) > 1:
-                market = symbol.split('#')[0]
-                symbol = symbol.split('#')[1]
+            if len(symbol.split("#")) > 1:
+                market = symbol.split("#")[0]
+                symbol = symbol.split("#")[1]
 
         if not market:
-            raise ValueError('市场参数错误, 市场参数不能为空.')
+            raise ValueError("市场参数错误, 市场参数不能为空.")
 
         return int(market), symbol
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def markets(self, **kwargs):
         """
         获取实时市场列表
@@ -495,7 +603,11 @@ class ExtQuotes(BaseQuotes):
         result = self.client.get_markets()
         return to_data(result, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def instrument(self, start=0, offset=100, **kwargs):
         """
         查询代码列表
@@ -508,7 +620,11 @@ class ExtQuotes(BaseQuotes):
         result = self.client.get_instrument_info(start=start, count=offset)
         return to_data(result, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def instrument_count(self):
         """
         市场商品数量
@@ -520,7 +636,11 @@ class ExtQuotes(BaseQuotes):
 
         return result
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
     def instruments(self, **kwargs):
         """
         查询所有代码列表
@@ -538,8 +658,12 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def quote(self, market='', symbol='', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def quote(self, market="", symbol="", **kwargs):
         """
         查询五档行情
 
@@ -553,8 +677,12 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def minute(self, market='', symbol='', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def minute(self, market="", symbol="", **kwargs):
         """
         查询分时行情
 
@@ -568,8 +696,12 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def minutes(self, market=None, symbol='', date='', **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def minutes(self, market=None, symbol="", date="", **kwargs):
         """
         查询历史分时行情
 
@@ -584,8 +716,12 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def bars(self, frequency='', market='', symbol='', start=0, offset=100, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def bars(self, frequency="", market="", symbol="", start=0, offset=100, **kwargs):
         """
         查询k线数据
 
@@ -598,14 +734,19 @@ class ExtQuotes(BaseQuotes):
         """
 
         frequency = get_frequency(frequency)
-
         market, symbol = self.validate(market, symbol)
-        result = self.client.get_instrument_bars(category=frequency, market=market, code=symbol, start=start, count=offset)
+        result = self.client.get_instrument_bars(
+            category=frequency, market=market, code=symbol, start=start, count=offset
+        )
 
-        return to_data(result, symbol=symbol, client=self, **kwargs)
+        return to_data(result, symbol=symbol, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def transaction(self, market=None, symbol='', start=0, offset=1800, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def transaction(self, market=None, symbol="", start=0, offset=1800, **kwargs):
         """
         查询分笔成交
 
@@ -621,8 +762,12 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    @retry(stop=stop_after_attempt(3), retry_error_callback=return_last_value, retry=(retry_if_exception_type() | retry_if_result(check_empty)))
-    def transactions(self, market=None, symbol='', date='', start=0, offset=1800, **kwargs):
+    @retry(
+        stop=stop_after_attempt(3),
+        retry_error_callback=return_last_value,
+        retry=(retry_if_exception_type() | retry_if_result(check_empty)),
+    )
+    def transactions(self, market=None, symbol="", date="", start=0, offset=1800, **kwargs):
         """
         查询历史分笔成交
 
@@ -635,6 +780,8 @@ class ExtQuotes(BaseQuotes):
         """
 
         market, symbol = self.validate(market, symbol)
-        result = self.client.get_history_transaction_data(market=market, code=symbol, date=int(date), start=start, count=offset)
+        result = self.client.get_history_transaction_data(
+            market=market, code=symbol, date=int(date), start=start, count=offset
+        )
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
